@@ -25,6 +25,6 @@ sc_adb_parse_devices(char *str, struct sc_vec_adb_devices *out_vec);
  * Warning: this function modifies the buffer for optimization purposes.
  */
 char *
-sc_adb_parse_device_ip_from_output(char *str);
+sc_adb_parse_device_ip(char *str);
 
 #endif
