@@ -29,6 +29,8 @@ struct sc_screen_otg_params {
     bool always_on_top;
     int16_t window_x; // accepts SC_WINDOW_POSITION_UNDEFINED
     int16_t window_y; // accepts SC_WINDOW_POSITION_UNDEFINED
+    uint16_t window_width;
+    uint16_t window_height;
     bool window_borderless;
 };
 
