@@ -11,7 +11,7 @@ net_connect_intr(struct sc_intr *intr, sc_socket socket, uint32_t addr,
                  uint16_t port);
 
 bool
-net_listen_intr(struct sc_intr *intr, sc_socket socket, uint32_t addr,
+net_listen_intr(struct sc_intr *intr, sc_socket server_socket, uint32_t addr,
                 uint16_t port, int backlog);
 
 sc_socket
