@@ -30,4 +30,14 @@ public final class Command {
         }
         return result;
     }
+
+    public static String execReadOutput(String... cmd) throws IOException, InterruptedException {
+        Process process = Runtime.getRuntime().exec(cmd);
+        String output = IO.toString(process.getInputStream());
+        int exitCode = process.waitFor();
+        if (exitCode != 0) {
+            throw new IOException("Command " + Arrays.toString(cmd) + " returned with value " + exitCode);
+        }
+        return output;
+    }
 }
