@@ -22,6 +22,7 @@ public class Options {
     private boolean clipboardAutosync = true;
     private boolean downsizeOnError = true;
     private boolean cleanup = true;
+    private boolean powerOn = true;
 
     // Options not used by the scrcpy client, but useful to use scrcpy-server directly
     private boolean sendDeviceMeta = true; // send device name and size
@@ -164,6 +165,14 @@ public class Options {
         this.cleanup = cleanup;
     }
 
+    public boolean getPowerOn() {
+        return powerOn;
+    }
+
+    public void setPowerOn(boolean powerOn) {
+        this.powerOn = powerOn;
+    }
+
     public boolean getSendDeviceMeta() {
         return sendDeviceMeta;
     }
