@@ -13,27 +13,30 @@ public final class ServiceManager {
     public static final String PACKAGE_NAME = "com.android.shell";
     public static final int USER_ID = 0;
 
-    private final Method getServiceMethod;
-
-    private WindowManager windowManager;
-    private DisplayManager displayManager;
-    private InputManager inputManager;
-    private PowerManager powerManager;
-    private StatusBarManager statusBarManager;
-    private ClipboardManager clipboardManager;
-    private ActivityManager activityManager;
-
-    public ServiceManager() {
+    private static final Method GET_SERVICE_METHOD;
+    static {
         try {
-            getServiceMethod = Class.forName("android.os.ServiceManager").getDeclaredMethod("getService", String.class);
+            GET_SERVICE_METHOD = Class.forName("android.os.ServiceManager").getDeclaredMethod("getService", String.class);
         } catch (Exception e) {
             throw new AssertionError(e);
         }
     }
 
-    private IInterface getService(String service, String type) {
+    private static WindowManager windowManager;
+    private static DisplayManager displayManager;
+    private static InputManager inputManager;
+    private static PowerManager powerManager;
+    private static StatusBarManager statusBarManager;
+    private static ClipboardManager clipboardManager;
+    private static ActivityManager activityManager;
+
+    private ServiceManager() {
+        /* not instantiable */
+    }
+
+    private static IInterface getService(String service, String type) {
         try {
-            IBinder binder = (IBinder) getServiceMethod.invoke(null, service);
+            IBinder binder = (IBinder) GET_SERVICE_METHOD.invoke(null, service);
             Method asInterfaceMethod = Class.forName(type + "$Stub").getMethod("asInterface", IBinder.class);
             return (IInterface) asInterfaceMethod.invoke(null, binder);
         } catch (Exception e) {
@@ -41,21 +44,28 @@ public final class ServiceManager {
         }
     }
 
-    public WindowManager getWindowManager() {
+    public static WindowManager getWindowManager() {
         if (windowManager == null) {
             windowManager = new WindowManager(getService("window", "android.view.IWindowManager"));
         }
         return windowManager;
     }
 
-    public DisplayManager getDisplayManager() {
+    public static DisplayManager getDisplayManager() {
         if (displayManager == null) {
-            displayManager = new DisplayManager(getService("display", "android.hardware.display.IDisplayManager"));
+            try {
+                Class<?> clazz = Class.forName("android.hardware.display.DisplayManagerGlobal");
+                Method getInstanceMethod = clazz.getDeclaredMethod("getInstance");
+                Object dmg = getInstanceMethod.invoke(null);
+                displayManager = new DisplayManager(dmg);
+            } catch (ClassNotFoundException | NoSuchMethodException | IllegalAccessException | InvocationTargetException e) {
+                throw new AssertionError(e);
+            }
         }
         return displayManager;
     }
 
-    public InputManager getInputManager() {
+    public static InputManager getInputManager() {
         if (inputManager == null) {
             try {
                 Method getInstanceMethod = android.hardware.input.InputManager.class.getDeclaredMethod("getInstance");
@@ -68,21 +78,21 @@ public final class ServiceManager {
         return inputManager;
     }
 
-    public PowerManager getPowerManager() {
+    public static PowerManager getPowerManager() {
         if (powerManager == null) {
             powerManager = new PowerManager(getService("power", "android.os.IPowerManager"));
         }
         return powerManager;
     }
 
-    public StatusBarManager getStatusBarManager() {
+    public static StatusBarManager getStatusBarManager() {
         if (statusBarManager == null) {
             statusBarManager = new StatusBarManager(getService("statusbar", "com.android.internal.statusbar.IStatusBarService"));
         }
         return statusBarManager;
     }
 
-    public ClipboardManager getClipboardManager() {
+    public static ClipboardManager getClipboardManager() {
         if (clipboardManager == null) {
             IInterface clipboard = getService("clipboard", "android.content.IClipboard");
             if (clipboard == null) {
@@ -96,7 +106,7 @@ public final class ServiceManager {
         return clipboardManager;
     }
 
-    public ActivityManager getActivityManager() {
+    public static ActivityManager getActivityManager() {
         if (activityManager == null) {
             try {
                 // On old Android versions, the ActivityManager is not exposed via AIDL,
